/*
 * Fig2dev: Translate Fig code to various Devices
 * Copyright (c) 1991 by Micah Beck
 * Parts Copyright (c) 1985-1988 by Supoj Sutanthavibul
 * Parts Copyright (c) 1989-2015 by Brian V. Smith
 * Parts Copyright (c) 2015-2023 by Thomas Loimer
 *
 * Any party obtaining a copy of these files is granted, free of charge, a
 * full and unrestricted irrevocable, world-wide, paid up, royalty-free,
 * nonexclusive right and license to deal in this software and documentation
 * files (the "Software"), including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, sublicense and/or sell copies
 * of the Software, and to permit persons who receive copies from any such
 * party to do so, with the only requirement being that the above copyright
 * and this permission notice remain intact.
 *
 */

/*
 * creationdate.h
 * Author: Thomas Loimer, 2016-06-28
 *
 */

#ifndef CREATIONDATE_H
#define CREATIONDATE_H

#if defined HAVE_CONFIG_H && !defined VERSION
#include "config.h"
#endif

#define	CREATION_TIME_LEN	36
extern int	creation_date(char *restrict buf);
extern int	creation_date_pdfmark(char *restrict buf);

#endif /* CREATIONDATE_H */
